==> alloy-ui-3.0.2-deprecated.1.jar: META-INF/resources/webjars/alloy-ui/3.0.2-deprecated.1/src/aui-form-builder/HISTORY.md <==
# AUI Form Builder

> Documentation and test modifications are not included in this changelog. For more details, see [full commit history](https://github.com/liferay/alloy-ui/commits/master/src/aui-form-builder).

## @VERSION@

* [AUI-2030](https://issues.liferay.com/browse/AUI-2030) A row with one col should be automatically added on last position when the last row have at least one field
* [AUI-2036](https://issues.liferay.com/browse/AUI-2036) AUI Form Builder Field Settings Modal should not overwrite Bootstrap 3 Modal css rules so that the layout keeps as similar as possible
* [AUI-2032](https://issues.liferay.com/browse/AUI-2032) Move out logic that displays field types modal
* [AUI-2016](https://issues.liferay.com/browse/AUI-2016) Remove column delete button from From Builder
* [AUI-2019](https://issues.liferay.com/browse/AUI-2019) The Active page number shouldn't appear over the Fields Panel
* [AUI-2018](https://issues.liferay.com/browse/AUI-2018) Create a template variable to form builder modal head content
* [AUI-2017](https://issues.liferay.com/browse/AUI-2017) Buttons in fields settings modal should follow bootstrap visual patterns
* [AUI-2000](https://issues.liferay.com/browse/AUI-2000) Add borders as separators on the grid
* [AUI-2014](https://issues.liferay.com/browse/AUI-2014) Changes the default value of the strings attribute from FormBuilderPageManager class
* [AUI-1993](https://issues.liferay.com/browse/AUI-1993) Change the add Field button
* [AUI-1995](https://issues.liferay.com/browse/AUI-1995) Extract the UI rendering logic from initializer
* [AUI-1962](https://issues.liferay.com/browse/AUI-1962) Updating the Page Manager to use a Popover with add/remove page instead of buttons
* [AUI-1992](https://issues.liferay.com/browse/AUI-1992) Extract the rendering pagination logic from initializer
* [AUI-1951](https://issues.liferay.com/browse/AUI-1951) Add attribute mode on Form Builder Pages
* [AUI-1930](https://issues.liferay.com/browse/AUI-1930) Change functionality of add cols
* [AUI-1931](https://issues.liferay.com/browse/AUI-1931) Add Tabs View mode
* [AUI-1928](https://issues.liferay.com/browse/AUI-1928) Fields should be moved between others field in a same col
* [AUI-1926](https://issues.liferay.com/browse/AUI-1926) Change functionality of move rows
* [AUI-1918](https://issues.liferay.com/browse/AUI-1918) Change functionality of remove rows
* [AUI-1917](https://issues.liferay.com/browse/AUI-1917) Add option to create Fields between two others Fields on the same column
* [AUI-1922](https://issues.liferay.com/browse/AUI-1922) Fixing localization issues on Form Builder
* [AUI-1921](https://issues.liferay.com/browse/AUI-1921) A row with one col should be automatically added on last position when the last row have at least two cols
* [AUI-1885](https://issues.liferay.com/browse/AUI-1885) Allows adding multiple fields on the same column
* [AUI-1887](https://issues.liferay.com/browse/AUI-1887) Form builder should have pages, not page breaks
* [AUI-1904](https://issues.liferay.com/browse/AUI-1904) Update textual content on Field Text
* [AUI-1902](https://issues.liferay.com/browse/AUI-1902) Form Builder fields toolbar buttons should not submit the form (reload the page) after clicked
* [AUI-1899](https://issues.liferay.com/browse/AUI-1899) Improve Form Builder visual interface
* [AUI-1866](https://issues.liferay.com/browse/AUI-1866) New line should be automatically added when a field is added on the last empty line
* [AUI-1897](https://issues.liferay.com/browse/AUI-1897) Make form builder field modal always have a single column
* [AUI-1853](https://issues.liferay.com/browse/AUI-1853) Use default checkbox/radio/dropdown for FormBuilderChoiceField
* [AUI-1844](https://issues.liferay.com/browse/AUI-1844) Trigger events for field creation/removal/edition
* [AUI-1877](https://issues.liferay.com/browse/AUI-1877) Move some form builder fields to Liferay Portal
* [AUI-1859](https://issues.liferay.com/browse/AUI-1859) User shouldn't be able to move a field inside another with movableContent false
* [AUI-1858](https://issues.liferay.com/browse/AUI-1858) FormBuilder should be able to receive layout as a configuration object
* [AUI-1810](https://issues.liferay.com/browse/AUI-1810) Form builder advanced field settings for mobile
* [AUI-1830](https://issues.liferay.com/browse/AUI-1830) Button to move field should be inside the field's toolbar
* [AUI-1840](https://issues.liferay.com/browse/AUI-1840) Field settings cancel and save buttons for mobile
* [AUI-1820](https://issues.liferay.com/browse/AUI-1820) Form Builder is not keyboard-accessible
* [AUI-1755](https://issues.liferay.com/browse/AUI-1755) Button for adding page breaks should be on the left of the button to add rows
* [AUI-1841](https://issues.liferay.com/browse/AUI-1841) Refactor field settings modal logic to separate file
* [AUI-1832](https://issues.liferay.com/browse/AUI-1832) Refactor aui-form-builder into smaller files
* [AUI-1831](https://issues.liferay.com/browse/AUI-1831) Change the way aui-data-editor updates the UI
* [AUI-1816](https://issues.liferay.com/browse/AUI-1816) Add placeholder as an advanced field setting
* [AUI-1826](https://issues.liferay.com/browse/AUI-1826) Rename FormBuilderPageBreak to FormBuilderPageBreakRow
* [AUI-1825](https://issues.liferay.com/browse/AUI-1825) Show asterisks beside each field's required setting
* [AUI-1811](https://issues.liferay.com/browse/AUI-1811) Change text field's multiline option to radio buttons instead of a button switch
* [AUI-1812](https://issues.liferay.com/browse/AUI-1812) Fix layout builder bug on IE
* [AUI-1802](https://issues.liferay.com/browse/AUI-1802) Add name as an advanced field setting
* [AUI-1824](https://issues.liferay.com/browse/AUI-1824) Change move col from events to attributes
* [AUI-1803](https://issues.liferay.com/browse/AUI-1803) Should be able to add and resize columns on main mode
* [AUI-1785](https://issues.liferay.com/browse/AUI-1785) Merge list and choice fields into a single field type
* [AUI-1800](https://issues.liferay.com/browse/AUI-1800) Add option on field toolbar to add a nested field
* [AUI-1791](https://issues.liferay.com/browse/AUI-1791) Changing a field's content should update its row height
* [AUI-1806](https://issues.liferay.com/browse/AUI-1806) Add button to cancel editing/creating a field
* [AUI-1792](https://issues.liferay.com/browse/AUI-1792) Fix bug when canceling field creation followed by editing a field
* [AUI-1750](https://issues.liferay.com/browse/AUI-1750) Create time field
* [AUI-1724](https://issues.liferay.com/browse/AUI-1724) Improve aui-boolean-data-editor's appearance
* [AUI-1784](https://issues.liferay.com/browse/AUI-1784) Convert existing form builder fields to separate rendering from edition logic
* [AUI-1770](https://issues.liferay.com/browse/AUI-1770) Field rendering should be separate from field editing
* [AUI-1738](https://issues.liferay.com/browse/AUI-1738) Update unique field types when fields change
* [AUI-1764](https://issues.liferay.com/browse/AUI-1764) Improve aui-options-data-editor's appearance
* [AUI-1776](https://issues.liferay.com/browse/AUI-1776) Improve appearance of rendered fields
* [AUI-1775](https://issues.liferay.com/browse/AUI-1775) Improve appearance of form builder's initial screen
* [AUI-1737](https://issues.liferay.com/browse/AUI-1737) Handle required fields on field settings modal
* [AUI-1723](https://issues.liferay.com/browse/AUI-1723) Field edition should have 2 columns on bigger screens
* [AUI-1763](https://issues.liferay.com/browse/AUI-1763) Update layout of page breaks and fields on regular mode
* [AUI-1749](https://issues.liferay.com/browse/AUI-1749) Fix title of modal for editing a field
* [AUI-1691](https://issues.liferay.com/browse/AUI-1691) Create date field
* [AUI-1759](https://issues.liferay.com/browse/AUI-1759) Form builder should have a header with an options menu
* [AUI-1693](https://issues.liferay.com/browse/AUI-1693) Create scale field
* [AUI-1694](https://issues.liferay.com/browse/AUI-1694) Create grid field
* [AUI-1720](https://issues.liferay.com/browse/AUI-1720) Allow moving fields inside existing fields
* [AUI-1690](https://issues.liferay.com/browse/AUI-1690) Create list field
* [AUI-1698](https://issues.liferay.com/browse/AUI-1698) Layout builder mode
* [AUI-1696](https://issues.liferay.com/browse/AUI-1696) Create sentence field
* [AUI-1697](https://issues.liferay.com/browse/AUI-1697) Add toolbar for fields
* [AUI-1689](https://issues.liferay.com/browse/AUI-1689) Create choice field
* [AUI-1685](https://issues.liferay.com/browse/AUI-1685) Button to add page breaks
* [AUI-1722](https://issues.liferay.com/browse/AUI-1722) Button to add rows
* [AUI-1684](https://issues.liferay.com/browse/AUI-1684) Add fields on empty columns
* [AUI-1688](https://issues.liferay.com/browse/AUI-1688) Create text field
* [AUI-1687](https://issues.liferay.com/browse/AUI-1687) Create base field class
* [AUI-1682](https://issues.liferay.com/browse/AUI-1682) Create page break abstraction
* [AUI-1714](https://issues.liferay.com/browse/AUI-1714) FormBuilder should update itself if `fieldTypes` attribute changes
* [AUI-1713](https://issues.liferay.com/browse/AUI-1713) Replace old form builder
* [AUI-1712](https://issues.liferay.com/browse/AUI-1712) Store field class info on FieldType
* [AUI-1647](https://issues.liferay.com/browse/AUI-1647) New form builder should know about the field types it will handle
* [AUI-1658](https://issues.liferay.com/browse/AUI-1658) Create new Field Type submodule of Form Builder

==> alloy-ui-3.0.3-deprecated.1.jar: META-INF/resources/webjars/alloy-ui/3.0.3-deprecated.1/src/aui-form-builder/HISTORY.md <==
# AUI Form Builder

> Documentation and test modifications are not included in this changelog. For more details, see [full commit history](https://github.com/liferay/alloy-ui/commits/master/src/aui-form-builder).

## @VERSION@

No registries yet.

## [3.0.3](https://github.com/liferay/alloy-ui/releases/tag/3.0.3)

* [AUI-2048](https://issues.liferay.com/browse/AUI-2048) Form Builder Add Field Button overlap each other on IE11

## [3.0.2](https://github.com/liferay/alloy-ui/releases/tag/3.0.2)

* [AUI-2030](https://issues.liferay.com/browse/AUI-2030) A row with one col should be automatically added on last position when the last row have at least one field
* [AUI-2036](https://issues.liferay.com/browse/AUI-2036) AUI Form Builder Field Settings Modal should not overwrite Bootstrap 3 Modal css rules so that the layout keeps as similar as possible
* [AUI-2032](https://issues.liferay.com/browse/AUI-2032) Move out logic that displays field types modal
* [AUI-2016](https://issues.liferay.com/browse/AUI-2016) Remove column delete button from From Builder
* [AUI-2019](https://issues.liferay.com/browse/AUI-2019) The Active page number shouldn't appear over the Fields Panel
* [AUI-2018](https://issues.liferay.com/browse/AUI-2018) Create a template variable to form builder modal head content
* [AUI-2017](https://issues.liferay.com/browse/AUI-2017) Buttons in fields settings modal should follow bootstrap visual patterns
* [AUI-2000](https://issues.liferay.com/browse/AUI-2000) Add borders as separators on the grid
* [AUI-2014](https://issues.liferay.com/browse/AUI-2014) Changes the default value of the strings attribute from FormBuilderPageManager class
* [AUI-1993](https://issues.liferay.com/browse/AUI-1993) Change the add Field button
* [AUI-1995](https://issues.liferay.com/browse/AUI-1995) Extract the UI rendering logic from initializer
* [AUI-1962](https://issues.liferay.com/browse/AUI-1962) Updating the Page Manager to use a Popover with add/remove page instead of buttons
* [AUI-1992](https://issues.liferay.com/browse/AUI-1992) Extract the rendering pagination logic from initializer
* [AUI-1951](https://issues.liferay.com/browse/AUI-1951) Add attribute mode on Form Builder Pages
* [AUI-1930](https://issues.liferay.com/browse/AUI-1930) Change functionality of add cols
* [AUI-1931](https://issues.liferay.com/browse/AUI-1931) Add Tabs View mode
* [AUI-1928](https://issues.liferay.com/browse/AUI-1928) Fields should be moved between others field in a same col
* [AUI-1926](https://issues.liferay.com/browse/AUI-1926) Change functionality of move rows
* [AUI-1918](https://issues.liferay.com/browse/AUI-1918) Change functionality of remove rows
* [AUI-1917](https://issues.liferay.com/browse/AUI-1917) Add option to create Fields between two others Fields on the same column
* [AUI-1922](https://issues.liferay.com/browse/AUI-1922) Fixing localization issues on Form Builder
* [AUI-1921](https://issues.liferay.com/browse/AUI-1921) A row with one col should be automatically added on last position when the last row have at least two cols
* [AUI-1885](https://issues.liferay.com/browse/AUI-1885) Allows adding multiple fields on the same column
* [AUI-1887](https://issues.liferay.com/browse/AUI-1887) Form builder should have pages, not page breaks
* [AUI-1904](https://issues.liferay.com/browse/AUI-1904) Update textual content on Field Text
* [AUI-1902](https://issues.liferay.com/browse/AUI-1902) Form Builder fields toolbar buttons should not submit the form (reload the page) after clicked
* [AUI-1899](https://issues.liferay.com/browse/AUI-1899) Improve Form Builder visual interface
* [AUI-1866](https://issues.liferay.com/browse/AUI-1866) New line should be automatically added when a field is added on the last empty line
* [AUI-1897](https://issues.liferay.com/browse/AUI-1897) Make form builder field modal always have a single column
* [AUI-1853](https://issues.liferay.com/browse/AUI-1853) Use default checkbox/radio/dropdown for FormBuilderChoiceField
* [AUI-1844](https://issues.liferay.com/browse/AUI-1844) Trigger events for field creation/removal/edition
* [AUI-1877](https://issues.liferay.com/browse/AUI-1877) Move some form builder fields to Liferay Portal
* [AUI-1859](https://issues.liferay.com/browse/AUI-1859) User shouldn't be able to move a field inside another with movableContent false
* [AUI-1858](https://issues.liferay.com/browse/AUI-1858) FormBuilder should be able to receive layout as a configuration object
* [AUI-1810](https://issues.liferay.com/browse/AUI-1810) Form builder advanced field settings for mobile
* [AUI-1830](https://issues.liferay.com/browse/AUI-1830) Button to move field should be inside the field's toolbar
* [AUI-1840](https://issues.liferay.com/browse/AUI-1840) Field settings cancel and save buttons for mobile
* [AUI-1820](https://issues.liferay.com/browse/AUI-1820) Form Builder is not keyboard-accessible
* [AUI-1755](https://issues.liferay.com/browse/AUI-1755) Button for adding page breaks should be on the left of the button to add rows
* [AUI-1841](https://issues.liferay.com/browse/AUI-1841) Refactor field settings modal logic to separate file
* [AUI-1832](https://issues.liferay.com/browse/AUI-1832) Refactor aui-form-builder into smaller files
* [AUI-1831](https://issues.liferay.com/browse/AUI-1831) Change the way aui-data-editor updates the UI
* [AUI-1816](https://issues.liferay.com/browse/AUI-1816) Add placeholder as an advanced field setting
* [AUI-1826](https://issues.liferay.com/browse/AUI-1826) Rename FormBuilderPageBreak to FormBuilderPageBreakRow
* [AUI-1825](https://issues.liferay.com/browse/AUI-1825) Show asterisks beside each field's required setting
* [AUI-1811](https://issues.liferay.com/browse/AUI-1811) Change text field's multiline option to radio buttons instead of a button switch
* [AUI-1812](https://issues.liferay.com/browse/AUI-1812) Fix layout builder bug on IE
* [AUI-1802](https://issues.liferay.com/browse/AUI-1802) Add name as an advanced field setting
* [AUI-1824](https://issues.liferay.com/browse/AUI-1824) Change move col from events to attributes
* [AUI-1803](https://issues.liferay.com/browse/AUI-1803) Should be able to add and resize columns on main mode
* [AUI-1785](https://issues.liferay.com/browse/AUI-1785) Merge list and choice fields into a single field type
* [AUI-1800](https://issues.liferay.com/browse/AUI-1800) Add option on field toolbar to add a nested field
* [AUI-1791](https://issues.liferay.com/browse/AUI-1791) Changing a field's content should update its row height
* [AUI-1806](https://issues.liferay.com/browse/AUI-1806) Add button to cancel editing/creating a field
* [AUI-1792](https://issues.liferay.com/browse/AUI-1792) Fix bug when canceling field creation followed by editing a field
* [AUI-1750](https://issues.liferay.com/browse/AUI-1750) Create time field
* [AUI-1724](https://issues.liferay.com/browse/AUI-1724) Improve aui-boolean-data-editor's appearance
* [AUI-1784](https://issues.liferay.com/browse/AUI-1784) Convert existing form builder fields to separate rendering from edition logic
* [AUI-1770](https://issues.liferay.com/browse/AUI-1770) Field rendering should be separate from field editing
* [AUI-1738](https://issues.liferay.com/browse/AUI-1738) Update unique field types when fields change
* [AUI-1764](https://issues.liferay.com/browse/AUI-1764) Improve aui-options-data-editor's appearance
* [AUI-1776](https://issues.liferay.com/browse/AUI-1776) Improve appearance of rendered fields
* [AUI-1775](https://issues.liferay.com/browse/AUI-1775) Improve appearance of form builder's initial screen
* [AUI-1737](https://issues.liferay.com/browse/AUI-1737) Handle required fields on field settings modal
* [AUI-1723](https://issues.liferay.com/browse/AUI-1723) Field edition should have 2 columns on bigger screens
* [AUI-1763](https://issues.liferay.com/browse/AUI-1763) Update layout of page breaks and fields on regular mode
* [AUI-1749](https://issues.liferay.com/browse/AUI-1749) Fix title of modal for editing a field
* [AUI-1691](https://issues.liferay.com/browse/AUI-1691) Create date field
* [AUI-1759](https://issues.liferay.com/browse/AUI-1759) Form builder should have a header with an options menu
* [AUI-1693](https://issues.liferay.com/browse/AUI-1693) Create scale field
* [AUI-1694](https://issues.liferay.com/browse/AUI-1694) Create grid field
* [AUI-1720](https://issues.liferay.com/browse/AUI-1720) Allow moving fields inside existing fields
* [AUI-1690](https://issues.liferay.com/browse/AUI-1690) Create list field
* [AUI-1698](https://issues.liferay.com/browse/AUI-1698) Layout builder mode
* [AUI-1696](https://issues.liferay.com/browse/AUI-1696) Create sentence field
* [AUI-1697](https://issues.liferay.com/browse/AUI-1697) Add toolbar for fields
* [AUI-1689](https://issues.liferay.com/browse/AUI-1689) Create choice field
* [AUI-1685](https://issues.liferay.com/browse/AUI-1685) Button to add page breaks
* [AUI-1722](https://issues.liferay.com/browse/AUI-1722) Button to add rows
* [AUI-1684](https://issues.liferay.com/browse/AUI-1684) Add fields on empty columns
* [AUI-1688](https://issues.liferay.com/browse/AUI-1688) Create text field
* [AUI-1687](https://issues.liferay.com/browse/AUI-1687) Create base field class
* [AUI-1682](https://issues.liferay.com/browse/AUI-1682) Create page break abstraction
* [AUI-1714](https://issues.liferay.com/browse/AUI-1714) FormBuilder should update itself if `fieldTypes` attribute changes
* [AUI-1713](https://issues.liferay.com/browse/AUI-1713) Replace old form builder
* [AUI-1712](https://issues.liferay.com/browse/AUI-1712) Store field class info on FieldType
* [AUI-1647](https://issues.liferay.com/browse/AUI-1647) New form builder should know about the field types it will handle
* [AUI-1658](https://issues.liferay.com/browse/AUI-1658) Create new Field Type submodule of Form Builder
